@@ -13,7 +13,7 @@ def make_values(values):
             for k, v in item.items():
                 walk(v, f"{path + (path and '.')}{k}")
         else:
-            value = json.dumps(item).replace('"', "")
+            value = json.dumps(item)  # .replace('"', "")
             flat_values.append(f"{path}={value}")
 
     for value in values:
@@ -32,11 +32,12 @@ def main():
         os.system(f'helm repo add {repo_name} {r["repository"]}')
         os.system("helm repo update")
         r["flat_values"] = ",".join(make_values(r["values"]))
-        r["ver"] = r.get("version") and f" --version {r['version']}" or ""
+        r["ver"] = f" --version {r['version']}" if r.get("version") else ""
         os.system(f"kubectl create ns {r['namespace']} &> /dev/null")
         cmd = string.Template(
             "helm upgrade -i $name $chart --namespace $namespace$ver --set $flat_values"
         ).substitute(r)
+        # print(cmd)
         os.system(cmd)
 
 
